# -*- coding: utf-8 -*-
"""
This file is part of checkmate, a meta code checker written in Python.

Copyright (C) 2015 Andreas Dewes, QuantifiedCode UG

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

error_data = {
    "E0101" : {
        "title" : "mixed spaces and tabs",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","correctness","maintainability"]
        },
    "E0111" : {
        "title" : "indentation not a multiple of four",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "E0112" : {
        "title" : "expected an indented block",
        "description" : "",
        "severity" : 2,
        "categories" : ["readability","correctness"]
        },
    "E0113" : {
        "title" : "unexpected indentation",
        "description" : "",
        "severity" : 2,
        "categories" : ["readability","correctness"]
        },
    "E0121" : {
        "title" : "continuation line under-indented for hanging indent",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0122" : {
        "title" : "continuation line missing indentation or outdented",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0123" : {
        "title" : "closing bracket does not match indentation of opening bracket’s line",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0124" : {
        "title" : "closing bracket does not match visual indentation",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0125" : {
        "title" : "continuation line with same indent as next logical line",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0126" : {
        "title" : "continuation line over-indented for hanging indent",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0127" : {
        "title" : "continuation line over-indented for visual indent",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0128" : {
        "title" : "continuation line under-indented for visual indent",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0129" : {
        "title" : "visually indented line with same indent as next logical line",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0131" : {
        "title" : "continuation line unaligned for hanging indent",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0133" : {
        "title" : "closing bracket is missing indentation",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0201" : {
        "title" : "whitespace after ‘(‘",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0202" : {
        "title" : "whitespace before ‘)’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0203" : {
        "title" : "whitespace before ‘:’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0211" : {
        "title" : "whitespace before ‘(‘",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0221" : {
        "title" : "multiple spaces before operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0222" : {
        "title" : "multiple spaces after operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0223" : {
        "title" : "tab before operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0224" : {
        "title" : "tab after operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0225" : {
        "title" : "missing whitespace around operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0226" : {
        "title" : "missing whitespace around arithmetic operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0227" : {
        "title" : "missing whitespace around bitwise or shift operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0228" : {
        "title" : "missing whitespace around modulo operator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0231" : {
        "title" : "missing whitespace after ‘,’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0241" : {
        "title" : "multiple spaces after ‘,’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0242" : {
        "title" : "tab after ‘,’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0251" : {
        "title" : "unexpected spaces around keyword / parameter equals",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0261" : {
        "title" : "at least two spaces before inline comment",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0262" : {
        "title" : "inline comment should start with ‘# ‘",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0265" : {
        "title" : "block comment should start with ‘# ‘",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0266" : {
        "title" : "too many leading ‘#’ for block comment",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0271" : {
        "title" : "multiple spaces after keyword",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0272" : {
        "title" : "multiple spaces before keyword",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0273" : {
        "title" : "tab after keyword",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0274" : {
        "title" : "tab before keyword",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0301" : {
        "title" : "expected 1 blank line, found 0",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0302" : {
        "title" : "expected 2 blank lines, found 0",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0303" : {
        "title" : "too many blank lines (3)",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0304" : {
        "title" : "blank lines found after function decorator",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0401" : {
        "title" : "multiple imports on one line",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0501" : {
        "title" : "line too long",
        "description" : "%(occurence.data.description)s",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0502" : {
        "title" : "the backslash is redundant between brackets",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0701" : {
        "title" : "multiple statements on one line (colon)",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0702" : {
        "title" : "multiple statements on one line (semicolon)",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0703" : {
        "title" : "statement ends with a semicolon",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0704" : {
        "title" : "multiple statements on one line",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0711" : {
        "title" : "comparison to None should be ‘if cond is None:’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0712" : {
        "title" : "comparison to True should be ‘if cond is True:’ or ‘if cond:’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0713" : {
        "title" : "test for membership should be ‘not in’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0714" : {
        "title" : "test for object identity should be ‘is not’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0721" : {
        "title" : "do not compare types, use ‘isinstance()’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability"]
        },
    "E0731" : {
        "title" : "do not assign a lambda expression, use a def",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "E0901" : {
        "title" : "syntax / indentation error",
        "description" : "",
        "severity" : 1,
        "categories" : ["correctness"]
        },
    "E0902" : {
        "title" : "IOError",
        "description" : "%(occurence.data.description)s",
        "severity" : 1,
        "categories" : ["correctness"]
        },
    "W0191" : {
        "title" : "indentation contains tabs",
        "description" : "",
        "severity" : 2,
        "categories" : ["readability","maintainability"]
        },
    "W0291" : {
        "title" : "trailing whitespace",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0292" : {
        "title" : "no newline at end of file",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0293" : {
        "title" : "blank line contains whitespace",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0391" : {
        "title" : "blank line at end of file",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0601" : {
        "title" : ".has_key() is deprecated, use 'in'",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0602" : {
        "title" : "deprecated form of raising an exception",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0603" : {
        "title" : "‘<>’ is deprecated, use ‘!=’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        },
    "W0604" : {
        "title" : "backticks are deprecated, use ‘repr()’",
        "description" : "",
        "severity" : 3,
        "categories" : ["readability","maintainability"]
        }
}